==> amulog-0.0.5.tar.gz: amulog-0.0.5/amulog/lt_import.py <==
#!/usr/bin/env python
# coding: utf-8

import os
import logging

from amulog import common
from amulog import strutil
from amulog import lt_common
from amulog import lt_search

_logger = logging.getLogger(__package__)


class LTGenImport(lt_common.LTGenStateless):

    def __init__(self, table, filename, mode, ltmap, lp, shuffle=False):
        super(LTGenImport, self).__init__(table)
        self._table = table
        self._d_def = common.IDDict(lambda x: tuple(x))
        self._ltmap = lt_search.init_searcher(ltmap)
        self._lp = lp
        self._open_def(filename, mode, shuffle)

    def _open_def(self, filename, mode, shuffle):
        if filename.strip() == "":
            errmes = "lt_import initialized with empty template set"
            _logger.info(errmes)
            return
        elif not os.path.exists(filename):
            errmes = ("log_template_import.def_path {0} is invalid".format(
                filename))
            raise IOError(errmes)

        cnt = 0
        with open(filename, 'r') as f:
            for line in f:
                if mode == "plain":
                    mes = line.rstrip("\n")
                elif mode == "manual":
                    pline = self._lp.process_message(strutil.add_esc(line))
                    mes = pline["words"]
                else:
                    raise ValueError("invalid import_mode {0}".format(
                        mode))
                if len(mes) == 0:
                    continue
                ltw, lts = self._lp.process_message(mes)
                self.add_definition(ltw)
                cnt += 1
        _logger.info("{0} template imported".format(cnt))
        if shuffle:
            self._ltmap.shuffle()

    def add_definition(self, ltw):
        defid = self._d_def.add(ltw)
        self._ltmap.add(defid, ltw)

    def update_definition(self, old_ltw, new_ltw):
        defid = self._ltmap.search(old_ltw)
        self._ltmap.remove(defid, old_ltw)
        self._d_def.set_item(defid, new_ltw)
        self._ltmap.add(defid, new_ltw)

    def generate_tpl(self, pline):
        defid = self._ltmap.search(pline["words"])
        if defid is None:
            return None
        else:
            tpl = self._d_def.get(defid)
            return tpl


def init_ltgen_import(conf, table, shuffle=False, **_):
    fn = conf.get("log_template_import", "def_path")
    mode = conf.get("log_template_import", "import_format")
    ltmap = conf.get("log_template_import", "search_method")
    from amulog import log_db
    lp = log_db.load_log2seq(conf)
    return LTGenImport(table, fn, mode, ltmap, lp, shuffle)

==> amulog-0.0.8.tar.gz: amulog-0.0.8/amulog/lt_import.py <==
#!/usr/bin/env python
# coding: utf-8

import os
import logging

from amulog import common
from amulog import strutil
from amulog import lt_common
from amulog import lt_search

_logger = logging.getLogger(__package__)


class LTGenImport(lt_common.LTGenStateless):

    def __init__(self, table, filename, mode, ltmap, lp, shuffle=False):
        super(LTGenImport, self).__init__(table)
        self._table = table
        self._d_def = common.IDDict(self._keyfunc)
        self._ltmap = lt_search.init_searcher(ltmap)
        self._lp = lp
        self._open_def(filename, mode, shuffle)

    @staticmethod
    def _keyfunc(x):
        return tuple(x)

    def _open_def(self, filename, mode, shuffle):
        if filename.strip() == "":
            errmes = "lt_import initialized with empty template set"
            _logger.info(errmes)
            return
        elif not os.path.exists(filename):
            errmes = ("log_template_import.def_path {0} is invalid".format(
                filename))
            raise IOError(errmes)

        cnt = 0
        with open(filename, 'r') as f:
            for line in f:
                if mode == "plain":
                    mes = line.rstrip("\n")
                elif mode == "manual":
                    pline = self._lp.process_message(strutil.add_esc(line))
                    mes = pline["words"]
                else:
                    raise ValueError("invalid import_mode {0}".format(
                        mode))
                if len(mes) == 0:
                    continue
                ltw, lts = self._lp.process_statement(mes)
                self.add_definition(ltw)
                cnt += 1
        _logger.info("{0} template imported".format(cnt))
        if shuffle:
            self._ltmap.shuffle()

    def add_definition(self, ltw):
        defid = self._d_def.add(ltw)
        self._ltmap.add(defid, ltw)

    def update_definition(self, old_ltw, new_ltw):
        defid = self._ltmap.search(old_ltw)
        self._ltmap.remove(defid, old_ltw)
        self._d_def.set_item(defid, new_ltw)
        self._ltmap.add(defid, new_ltw)

    def generate_tpl(self, pline):
        defid = self._ltmap.search(pline["words"])
        if defid is None:
            return None
        else:
            tpl = self._d_def.get(defid)
            return tpl


def init_ltgen_import(conf, table, shuffle=False, **_):
    fn = conf.get("log_template_import", "def_path")
    mode = conf.get("log_template_import", "import_format")
    ltmap = conf.get("log_template_import", "search_method")
    from amulog import log_db
    lp = log_db.load_log2seq(conf)
    return LTGenImport(table, fn, mode, ltmap, lp, shuffle)
